@@ -2,7 +2,7 @@
 #define IMSS_H
 
 extern i_img *
-imss_win32(unsigned hwnd, int include_decor, int left, int top, int right, int bottom);
+imss_win32(unsigned hwnd, int include_decor, int left, int top, int right, int bottom, int display);
 
 extern i_img *
 imss_x11(unsigned long display, int window_id, int left, int top, int right, int bottom);
